# Generated by roxygen2: do not edit by hand

S3method(plot,longitree)
S3method(plot,threetrees)
S3method(predict,longitree)
S3method(predict,threetrees)
S3method(print,longitree)
S3method(print,threetrees)
S3method(summary,longitree)
S3method(summary,threetrees)
export(longitree)
export(longitrees)
export(selectionplot)
export(threetrees)
export(treeplot)
import(ggparty)
import(ggplot2)
import(graphics)
importFrom(lme4,fixef)
importFrom(lme4,lmer)
importFrom(partykit,nodeapply)
importFrom(partykit,nodeids)
importFrom(partykit,party)
importFrom(partykit,partynode)
importFrom(partykit,partysplit)
importFrom(stats,setNames)
importFrom(stats,terms.formula)
importFrom(utils,globalVariables)
useDynLib(longitree, .registration = TRUE)
