% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{ltreedata}
\alias{ltreedata}
\title{Sample longitudinal data for decision tree examples}
\format{
A data frame with 500 rows and 7 variables:
\describe{
\item{y}{Response variable (continuous).}
\item{subject}{Subject identifier (integer, 1--50).}
\item{time}{Time point (integer, 1--10).}
\item{x1}{Baseline covariate 1 (integer, 1--10).}
\item{x2}{Baseline covariate 2 (integer, 1--10).}
\item{x3}{Baseline covariate 3 (integer, 1--6).}
\item{x4}{Baseline covariate 4 (integer, 1--12).}
}
}
\usage{
ltreedata
}
\description{
A sample balanced longitudinal dataset with 50 subjects
observed at 10 equally spaced time points.
}
\keyword{datasets}
